Ext.define('DSS.addon.IlluminantType', {
    extend : 'DSS.component.Base',
    mixins : {
        observable : 'Ext.util.Observable'
    },
    vendorGrid : null,
    typeGrid : null,
    grafic : null,
    macPanel : null,
    iDefaultWidth : 150,
    iDefaultHeight : 293,
    iSelectedID:null,
    setHeight : function(oHeight) {
        this.macPanel.setHeight(oHeight - 125);
        this.iDefaultHeight = oHeight - 127;
        if (this.vendorGrid != null)
            this.vendorGrid.setHeight(this.iDefaultHeight);
        if (this.typeGrid != null)
            this.typeGrid.setHeight(this.iDefaultHeight);
        this.callParent(arguments);
    },
    initStores : function() {
        if (Ext.data.StoreManager.lookup('illuminateChartValues') == null) {
            Ext.create('Ext.data.Store', {
                storeId : 'illuminateChartValues',
                fields : [ 'id','value'],
                proxy : {
                    type : 'memory',
                    reader : {
                        type : 'json',
                        root : 'items'
                    }
                }
            });   
        }
    },
    constructGrid : function() {
        var lvlTypeStore = Ext.create('Ext.data.Store', {
            fields : [ 'id', 'type', 'socket','capatility' ],
            proxy : {
                type : 'memory',
                reader : {
                    type : 'json',
                    root : 'items'
                }
            }
        });
        
        this.vendorGrid = Ext.create('Ext.grid.Panel', {
            height : this.iDefaultHeight,
            width : 150,
            autoScroll : true,
            viewConfig : {
                stripeRows : true
            },
            store : Ext.data.StoreManager.lookup('illuminateVendorStore'),
            columns : [ {
                sortable : false,
                hideable : false,
                text : _('Vendor'),
                dataIndex : 'vendor',
                flex : 1
            } ]
        });
        this.vendorGrid.parent = this;

        this.typeGrid = Ext.create('Ext.grid.Panel', {
            height : this.iDefaultHeight,
            width : 624,
            autoScroll : true,
            viewConfig : {
                stripeRows : true
            },
            store:Ext.data.StoreManager.lookup('illuminateTypeStore'),
            columns : [ {
                sortable : false,
                hideable : false,
                text : _('Socket'),
                dataIndex : 'socket',
                width: 40
            },
            {
                sortable : false,
                hideable : false,
                text : _('Type'),
                dataIndex : 'name',
                flex : 4
            },{
                sortable : false,
                hideable : false,
                text : _('Power'),
                dataIndex : 'watt',
                renderer: function (value)
                {
                	return value + _('W');
                }
            },{
                sortable : false,
                hideable : false,
                text : _('Colortemperature'),
                dataIndex : 'colortemp'
            },           
            {
                sortable : false,
                hideable : false,
                text : _('dimming capatility'),
                dataIndex : 'abilitiy',
                renderer: function (value)
                {
                    switch(value) {
                        case 2: 
                            return '<img src="images/status_ok.png"/>';
                            break;
                        case 1:
                        case 1: 
                            return '<img src="images/status_critical.png"/>';
                            break;
                        case 0:
                            return '<img src="images/status_error.png"/>';
                            break;
                        default: 
                            return '<img src="images/status_critical.png"/>';
                            break;
                    }
                },
                width: 50
            } ]
        });
        this.typeGrid.parent = this;

        
        this.vendorGrid.on('itemclick', function(grid, record) {
            Ext.data.StoreManager.lookup('illuminateTypeStore').clearFilter();
            Ext.data.StoreManager.lookup('illuminateTypeStore').filter('manufactureID',record.get('id'));
            this.parent.macPanel.doLayout();
        });
        

        this.typeGrid.on('selectionchange', function(model,record) {
            Ext.data.StoreManager.lookup('illuminateChartValues').removeAll();
            if (record.length>0) {
            	this.parent.iSelectedID=record[0].get('id');
                this.parent.dimmbarPanel.setValue(_('Yes') + ' 100% - ' + record[0].get('dimmMinimum') +"%");
            	this.parent.lumenPanel.setValue(record[0].get('lumen') + _('lm'));
            	this.parent.winkelPanel.setValue(record[0].get('winkel') + "&deg;");
            	this.parent.eanPanel.setValue(record[0].get('ean'));
            	this.parent.bewertungsPanel.setValue(record[0].get('abilityDetail'));
            	
                var oValues=record[0].get('curveValues');
                oValues.sort(function (a,b){return a.id-b.id;});
                for (var iIndex=0;iIndex<oValues.length;iIndex++) {
                    Ext.data.StoreManager.lookup('illuminateChartValues').add({id:iIndex,value:oValues[iIndex].value});
                }
                this.parent.macPanel.doLayout();
            }
        });

    },
    constructor : function(config) {

        
        this.initStores();
        this.constructGrid();
        this.macPanel = Ext.create('Ext.panel.Panel', {
            border : '0',
            autoScroll : true,
            height : 200,
            width : 774,
            layout : {
                type : 'hbox',
                flex:0
            },
            items : [ this.vendorGrid,this.typeGrid  ],
            scroll : 'horizontal'
        });

        this.grafic = Ext.create('Ext.chart.Chart', {
            store:Ext.data.StoreManager.lookup('illuminateChartValues'),
            height : 100,
            width: 524,
            animate: true,
            series: [ {
                         type: 'line',
                         xField: 'id',
                         yField: 'value',
                         fill: true,
                         markerConfig: {
                             type: 'circle',
                             radius: 4,
                             'fill': '#ffff00'
                         }
                     }]
        });
        
        this.bewertungsPanel=Ext.create('Ext.form.field.Display',{
            width:524,
            height:20,
            fieldLabel:'Bewertung',
            value:_('Leuchtmittel w&auml;hlen')
        });
        
        this.eanPanel=Ext.create('Ext.form.field.Display',{
            height:20,
            fieldLabel:'EAN',
            value:_('Leuchtmittel w&auml;hlen')
        });
        
        this.winkelPanel=Ext.create('Ext.form.field.Display',{
            height:20,
            fieldLabel:'Abstrahlwinkel',
            value:_('Leuchtmittel w&auml;hlen')
        });
        
        this.lumenPanel=Ext.create('Ext.form.field.Display',{
            height:20,
            fieldLabel:'Lumen',
            value:_('Leuchtmittel w&auml;hlen')
        });
        
        this.dimmbarPanel=Ext.create('Ext.form.field.Display',{
            height:20,
            fieldLabel:'Dimmbar',
            value:_('Leuchtmittel w&auml;hlen')
        });
        
        
        this.bottomLeftContainer=Ext.create('Ext.panel.Panel', {
            border : 0,
            height : 120,
            width : 524,
            layout : {
                type : 'vbox',
                flex:0
            },
            items : [this.grafic, this.bewertungsPanel],
            scroll : 'horizontal'
        });
        
        this.bottomRightContainer=Ext.create('Ext.panel.Panel', {
            border : 0,
            height : 120,
            width : 250,
            layout : {
                type : 'vbox',
                flex:0
            },
            items : [this.eanPanel,this.winkelPanel, this.lumenPanel, this.dimmbarPanel],
            scroll : 'horizontal'
        });
        

        
        this.bottomContainer=Ext.create('Ext.panel.Panel', {
            border : 0,
            height : 120,
            width : 774,
            layout : {
                type : 'hbox',
                flex:0
            },
            items : [ this.bottomLeftContainer,this.bottomRightContainer ],
            scroll : 'horizontal'
        });
        
        
        Ext.apply(this, {
            layout : {
                type : 'vbox'
            },
           
            items : [ this.macPanel, this.bottomContainer ]
        });
        this.callParent(arguments);
    },
    reset : function() {
        this.setValue(null);
    },
    setValue : function(value) {
        this.iSelectedID=value;
        var oRecord=Ext.data.StoreManager.lookup('illuminateTypeStore').findRecord('id',value,0,false,false,true);
		if (oRecord!=null) {
			var manuID=oRecord.get('manufactureID');
			var oVendorIndex=Ext.data.StoreManager.lookup('illuminateVendorStore').find('id',manuID,0,false,false,true);
			if (oVendorIndex!=-1) {
				this.vendorGrid.getSelectionModel().select(oVendorIndex);
				Ext.data.StoreManager.lookup('illuminateTypeStore').filter('manufactureID',manuID);
				var iRecordIndex=Ext.data.StoreManager.lookup('illuminateTypeStore').find('id',value,0,false,false,true);
				this.typeGrid.getSelectionModel().select(iRecordIndex);
			}
		}
    },
    isValid : function() {
        return true;
    },
    getValue : function() {
        return this.iSelectedID;
    }
});
